#
# spec file for package xdg-utils
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           xdg-utils
Version:        20160610
Release:        6.3
Summary:        Utilities to uniformly interface desktop environments
License:        MIT
Group:          System/GUI/Other
Url:            http://portland.freedesktop.org/
# http://portland.freedesktop.org/download/xdg-utils-%%{version}.tar.gz
Source:         xdg-utils-%{version}.tar.xz
# PATCH-FEATURE-OPENSUSE install-some-more-scripts.diff jslaby@suse.cz
Patch0:         install-some-more-scripts.diff
# PATCH-FIX-UPSTREAM xdg-terminal-fix-gsettings.patch fdo#93231 ronisbr@gmail.com
Patch1:         xdg-terminal-fix-gsettings.patch
# PATCH-FIX-UPSTREAM fix-enlightenment-support.patch fdo#88280 simon@simotek.net
Patch2:         fix-enlightenment-lxqt-support.patch
# PATCH-FIX-UPSTREAM xdg-terminal-fix-terminal--x-arg.patch fdo#93231 sor.alexei@meowr.ru -- https://bugs.freedesktop.org/show_bug.cgi?id=93231#c5
Patch3:         xdg-terminal-fix-terminal--x-arg.patch
# PATCH-FIX-UPSTREAM (2 patches) xdg-mime / xdg-open generic implementations only return 1 item sflees@suse.de (boo#979265)
Patch4:         common-vendor-dirs-in-desktop_to_binary.patch
Patch5:         xdg-mime-return-existing-desktop-files.patch
BuildRequires:  make
# for xmlto to be able to generate text from html
BuildRequires:  w3m
BuildRequires:  xmlto
Requires:       perl
Requires:       perl-Net-DBus
Requires:       perl-X11-Protocol
Requires:       which
%if 0%{?suse_version} > 1110
BuildArch:      noarch
%else
BuildRequires:  xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%endif

%description
The xdg-utils package is a set of simple scripts that provide basic
desktop integration functions for any Free Desktop, such as Linux.

They are intended to provide a set of de-facto standards.
This means that:
 * Third party software developers can rely on these xdg-utils for
   all of their simple integration needs.

*  Developers of desktop environments can make sure that their
   environments are well supported.

   If a desktop developer wants to be certain that their
   environment functions with all third party software, then can
   simply make sure that these utilities work properly in their
   environment.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1

%build
%configure
make %{?_smp_mflags}

%install
%make_install

%files
%defattr(-,root,root)
%doc ChangeLog LICENSE README TODO
%{_bindir}/xdg-desktop-icon
%{_bindir}/xdg-desktop-menu
%{_bindir}/xdg-email
%{_bindir}/xdg-icon-resource
%{_bindir}/xdg-mime
%{_bindir}/xdg-open
%{_bindir}/xdg-su
%{_bindir}/xdg-screensaver
%{_bindir}/xdg-settings
%{_bindir}/xdg-terminal
%{_mandir}/man1/xdg-desktop-icon.1%{?ext_man}
%{_mandir}/man1/xdg-desktop-menu.1%{?ext_man}
%{_mandir}/man1/xdg-email.1%{?ext_man}
%{_mandir}/man1/xdg-icon-resource.1%{?ext_man}
%{_mandir}/man1/xdg-mime.1%{?ext_man}
%{_mandir}/man1/xdg-open.1%{?ext_man}
%{_mandir}/man1/xdg-terminal.1%{?ext_man}
%{_mandir}/man1/xdg-screensaver.1%{?ext_man}
%{_mandir}/man1/xdg-settings.1%{?ext_man}
%{_mandir}/man1/xdg-su.1%{?ext_man}

%changelog
* Thu Nov 17 2016 sflees@suse.de
- Take version from tumbleweed (I didn't know this was branched from 42.1)
  * xdg-mime: support for KDE Frameworks 5.6
  * xdg-mime does not write the file it reads in a query (BR95051)
  * xdg-screensaver: Add cinnamon-screensaver D-Bus API support.
  * xdg-open: standardize output redirection style
- Take version from tumbleweed (patch fixes)
  * xdg-mime-return-existing-desktop-files.patch
  * common-vendor-dirs-in-desktop_to_binary.patch
- Add LXQt Support boo#959912
  * fix-enlightenment-support.patch now fix-enlightenment-lxqt-support.patch
* Sat Feb  6 2016 sor.alexei@meowr.ru
- Fix a mistake with build architecture.
* Fri Jan 22 2016 sor.alexei@meowr.ru
- Update to 20151219:
  * xdg-open: Improve fallbacks, add open_generic (almost)
    everywhere (fdo#93442).
  * xdg-open: Standardise output redirection style.
- Add xdg-terminal-fix-terminal--x-arg.patch: fix for "-x" usage
  (default option for MATE and GNOME terminals).
- Spec cleanup.
* Sun Dec  6 2015 jslaby@suse.com
- update to 20151112
  * xdg-utils-common: bump version number
  * Check for $WAYLAND_DISPLAY as well as $DISPLAY.
* Thu Dec  3 2015 ronisbr@gmail.com
- Add patch `xdg-terminal-fix-gsettings.patch` to fix upstream
  bfo#93231
* Tue Nov  3 2015 jslaby@suse.com
- update to 20151005
  * ChangeLog: add debian bug number
  * ChangeLog: add some space
  * xdg-open: Add proper quoting so that files with spaces in their names can be opened in generic mode and LXDE
  * t-xdg-open: test opening files with spaces in LXDE too
  * t-xdg-open: quote file variable properly in mock_xdg_mime()
  * xdg-open: Fix regression in generic mode (wrong variable name)
  * t-xdg-open: improve mocking of xdg-mime (check all arguments)
  * t-xdg-open: can open -> opens
  * t-xdg-open: test that it can open files with spaces in their names in generic mode
  * t-xdg-open: move generic open file testing to its own function
  * t-xdg-open: move xdg-mime mocking to its own function
  * t-xdg-open: use the mock script argument instead of writing a mock script manually
  * oops, fix spelling of name
  * xdg-screensaver: Run 'xset -dpms' and then 'xset +dpms' to reset the DPMS timer
  * add .dir-locals.el that switches off change-log-mode in Emacs for ChangeLog
  * add t-xdg-screensaver
  * xdg-screensaver: handle XDG_CURRENT_DESKTOP=X-Generic
  * test-lib: take arbitrary script code as argument to mock
  * remove org.freedesktop.ScreenSaver support from TODO
  * release xdg-utils 1.1.0
  * xdg-email: Remove obsolete references to http://portland.freedesktop.org/wiki/EmailConfig from the manual
  * add releaseinfo element to xdg-settings manual
  * Add references to specifications to the manuals
  * xdg-open: use sed to remove file URL query strings, the shell will interpret '?' as any character despite escaping
  * xdg-open: Only strip queries (?) and fragments (#) from file URLs before decoding them, not from (decoded) paths
  * t-xdg-open: test that it can open files with # characters in generic mode
  * t-xdg-open: test that it can open files in generic mode
  * t-xdg-open: under -> in
  * t-xdg-open: separate out proper testcases
  * autotests: don't print test filename
  * xdg-email: Rewrite open_kde()
  * t-xdg-email: update KDE tests
  * autotests: Add t-xdg-email.sh with KDE5 test
  * Revert "Remove .sh extension from autotests"
  * Remove .sh extension from autotests
  * +x on t-xdg-settings.sh
  * xdg-settings: apply basename to browser desktop file in generic mode
  * t-xdg-settings: test $BROWSER in generic mode
  * xdg-settings: Add a proper generic mode.
  * xdg-settings: Detect generic DE instead of failing. (Debian bug #787791)
  * autotests: add t-xdg-settings.sh
  * add /failed-tests to autotests/.gitignore
  * test-lib: add mock_output()
  * xdg-open, xdg-email: Add iceweasel to the list of fallback browsers. (Debian bug #788047)
  * add Debian bug number to ChangeLog
  * test-lib: better assertion failed message for assert_run
  * indentation
  * use $LABHOME/.local/share for $XDG_DATA_HOME
  * is -> are
  * t-xdg-open: also test Cinnamon
  * xdg-open: Fall back to generic mode if gvfs-open and gnome-open are missing. Don't try to use gnome-open if running under GNOME 3 or Cinnamon.
  * t-xdg-open.sh: test that gnome3 and gnome2 fall back to generic if gvfs-open and gnome-open are missing
  * xdg-mime: Check ~/.config/mimeapps.list instead of ~/.config/applications/mimeapps.list when looking for default application.
  * test-lib: always mock x-www-browser so we have a fallback
  * put default apps in $XDG_CONFIG_HOME/mimeapps.list
  * test-lib: add mock_desktop_file and mock_default_app
  * test-lib: add XDG_CONFIG_HOME and create it in reset_lab_()
  * test-lib: nicer output formatting
  * merge t-xdg-open-url and t-xdg-open-file into t-xdg-open
  * autotests: set COMMAND_TESTED in each test file and rename test_that to test_that_it which prints the command to be tested. Also remove test file printing from makefile
  * test-lib: don't trace which commands are run unless TRACE_RUN=1
  * add test_that invocations before every test
  * test-lib: rename setup_lab to reset_lab_
  * test-lib: add test_that function that resets the lab, echoes the argument and records it
  * test-lib: add XDG_CONFIG_DIRS to environment
  * autotests: add LABHOME directory lab/home and set HOME to LABHOME when running xdg-utils commands
  * test-lib: clear $BROWSER in setup_lab
  * xdg-utils-common: Add support for GNOME-Flashback:GNOME value X-Generic.
  * xdg-open: Percent-decode file:// URLs in open_lxde and add testcase. (BR89654)
  * autotests/Makefile.in: use rm -f insted of -rm
  * autotests: remove Makefile in distclean target
  * speling
  * xdg-icon-resouce: Don't try to install anything into empty $icon_dir's.
  * add autotests/t-xdg-icon-resource.sh
  * test-lib.sh: pass on XDG_UTILS_DEBUG_LEVEL in run()
  * autotests: add autotest target to subdir makefile
  * test-lib.sh: add assert_file_exists
  * test-lib.sh: create hicolor icon directories in lab
  * add changelog entry: xdg-open: Try www-browser first of the non-X browsers.
  * Merge branch 'feature/try-www-browser-first' into upstream
  * add changelog entry: xdg-open: Add support for running without X.
  * Merge branch 'feature/no-X' into upstream
  * changelog message: xdg-email: Add support for the  environment variable.
  * Merge branch 'feature/mailer-envvar' into upstream
  * thank Ben Hutchings for the gnome-screensaver perl script
  * add changelog message for the gnome-screensaver suspend perl code
  * Merge branch 'bug/gnome3-screensaver-suspend' into upstream
  * use Makefile.in in autotests for consistency
  * changelog entry for the new automatic test suite
  * check that $BROWSER with %%s is safe from shell injection
  * use empty default target in autotests/Makefile to avoid running tests as part of the build process
  * Merge branch 'bug/prefer-browser-envvar' into feature/autotests
  * run tests with sh in case they lack the x-bit
  * add extra blank line after test failures output
  * add autotests to SUBDIRS in top-level makefile and add clean target
  * collect failed assertions instead of aborting
  * check that $BROWSER overrides mimeapps.list in generic mode
  * add BROWSER to env
  * add autotest target to top makefile
  * Try $BROWSER first in generic mode if it is set by the user.
  * add generic and lxde tests to t-xdg-open-url.sh
  * add test t-xdg-mime-query-default.sh
  * make applications directories and add assert_equal() function
  * Introduce an automated test suite.
  * move www-browser to separate feature/patch
  * Try www-browser first when running without $DISPLAY.
  * Add support for using xdg-open and xdg-email without X.
  * Add $MAILER support to xdg-email.
  * Use DBus API for GNOME since gnome-screensaver-command --poke has been removed
  * xdg-email: Recipients passed to Thunderbird are incorrectly quoted (BR91996)
  * xdg-email: generic mode does nothing (BR92008)
  * xdg-email: Icedove support (BR91997)
  * xdg-email: bashism: relies on bash's echo in run_thunderbird() (BR91990)
  * xdg-open shell script contains bash code (BR86028)
  * xdg-open: Add support for multi-word $BROWSER commands (BR91989)
  * Changelog for previous commit
  * xdg-icon-resource: quote var expansions
  * xdg-icon-resource: does not support filenames with spaces (BR91758)
  * xdg-screensaver support for xautolock (BR89655)
  * xdg-screensaver: fix a comment typo
  * xdg-mime: remove obsolete workaround for bug #33094
  * amend changelog to be more specific
  * add changelog for last batch of commits
  * xdg-terminal: add support for GNOME3, Cinnamon, MATE
  * xdg-su: add support for Cinnamon
  * xdg-settings: add support for all GVfs-based desktops
  * xdg-open: use cygstart on Cygwin
  * xdg-open: fix operation on Darwin
  * xdg-open: add support for Cinnamon
  * xdg-mime: add support for all GVfs-based desktops
  * xdg-mime: implement Mime Apps Spec
  * xdg-file-dialog: use zenity on Cinnamon and MATE
  * xdg-email: add support for all GVfs-based desktops
  * xdg-copy: add support for all GVfs-based desktops
  * Add detection of Cinnamon desktop
  * Improve detection of GNOME Classic and Flashback sessions
  * followup commit, copy-n-paste fail
  * xdg-email: generic check for assigned mailto (BR79929)
  * xdg-mime: search mimeinfo.cache in $xdg_user_dir too (BR31629)
  * typo from previous commit
  * xdg-open: does not exit if it does not recognize the mimetype (BR89902)
  * xdg-desktop-menu:  does not support filenames with spaces (BR66605)
  * xdg-open:  fix regression where & gets replaced with \\& in URLs
  * xdg-email: thunderbird launch in xdg-email in gnome3 fails (BR61475)
  * add ChangeLog entry for previous commit
  * xdg-mime: do not report multiple desktop files (BR60329)
  * one more s/$arg/$target/ rename fix for prior commit
  * xdg-open: safer xdg-open (BR89130)
- Remove: xdg-mime-generic-do-not-return-more-than-one-default.patch
- Remove: xdg-screensaver-gnome-perl.diff
* Tue Jan 20 2015 jslaby@suse.com
- update to 20150119
  * xdg-open: Improve performance of get_key function
  * xdg-open: better fix for command injection vulnerability (bnc#913676)
  * xdg-screensaver: Change screensaver_freedesktop's interpretation of GetActive
  * xdg-mime: dereference symlinks when using mimetype or file
  * xdg-open: command injection vulnerability
  * xdg-screensaver should control X11's screensaver in xfce as fallback
* Sun Dec 28 2014 simon@simotek.net
- add fix-enlightenment-support.patch
  * xdg-su and xdg-terminal both detected enlightenment then did nothing
  * xdg-su and xdg-terminal both use terminology rather then xterm now
* Thu Nov 27 2014 jslaby@suse.com
- Update to 20141009:
  * more of plasma5
- xdg-mime-generic-do-not-return-more-than-one-default.patch (bnc#906625)
- .spec cleanup
* Tue Sep 23 2014 hrvoje.senjan@gmail.com
- Update to 20140922:
  * Initial support for Plasma5
  * XFCE .desktop file created for browser selection is broken
    (fdo#56092)
  * Unnecessary filtering file:// for pcmanfm (fdo#63153)
  * fails if user sets a custom IFS environment variable
    (fdo#81386)
  * xdg-utils-common is broken, xdg-open uses bashism (fdo#83979)
  * xdg-email: do not encode - character
* Mon Jun 30 2014 fcrozat@suse.com
- Update to 20140630:
  * manpage for xdg-su and xdg-terminal
  * xdg-terminal: better support for screen and rxvt variants
  * add xdg-settings tool
  * improve KDE detection
  * xdg-open: various fixes
  * xdg-screensaver: use D-Bus api to lock GNOME screensaver
* Thu Jan  9 2014 jslaby@suse.com
- update to 20140109
  * xdg-mime: generic, handle filenames with colon (bnc#854777)
  * xdg-desktop-menu: improperly check for vendor prefix ...
  * xdg-screensaver: Support MATE desktop part 2
  * xdg-desktop-menu: Unquoted file name (BR69399)
  * xdg-open: Detect Enlightenment and make use of it
  * xdg-open: be more paranoid in escaping
- xdg-open-be-more-paranoid-in-escaping.patch: remove
* Wed Oct  2 2013 fcrozat@suse.com
- Requires which package, otherwise most xdg scripts won't work
  properly.
* Mon May 20 2013 jslaby@suse.com
- update to 20121008
  * xdg-mime does not search mimeinfo.cache (BR31629)
- xdg-open-be-more-paranoid-in-escaping.patch: xdg-open: be more
  paranoid in escaping (bnc#811959)
* Mon Sep 17 2012 jslaby@suse.com
- update to snapshot from 20120916
  * mate support added
  * switch to local _service
  * fix bad date in the file name
* Mon Aug 20 2012 jslaby@suse.de
- update to snapshot from 20120809
  * fix xdg-su for icewm (bnc#776202)
  * remove xfce-su.diff (merged)
  * few fixes (syntax errors in some cases and such)
  * see ChangeLog for updates
* Thu Jun 28 2012 jslaby@suse.de
- update to snapshot from 20120310
  * many local patches are gone, since they were merged
  * fixes many issues (see bnc#749612, bnc#703396, bnc#752977)
  * see ChangeLog for updates
- clean the specfile a bit
* Mon May 21 2012 vargusz@fazekas.hu
- Fix xdg-screensaver issues with Gnome 3 (bnc#559110)
* Sun Oct 23 2011 pascal.bleser@opensuse.org
- add xdg-terminal
* Sat May 21 2011 ctrippe@opensuse.org
- Fix xdg-open to probably parse the version for KDE4 (bnc#694543)
* Tue Jul 20 2010 reddwarf@opensuse.org
- Fix screensaver handling in KDE4
* Sun Mar 28 2010 andrea@opensuse.org
- added xdg-utils-1.0.2-bnc591714.patch to fix bnc#591714
* Thu Jan 14 2010 andrea@opensuse.org
- added LXDE support
* Sun Aug 16 2009 aj@suse.de
- Add some support for KDE4, taken from upstream CVS.
* Thu Feb  7 2008 dmueller@suse.de
- fix command injection (#bnc355061, CVE-2008-0386)
* Mon Oct 22 2007 stbinner@suse.de
- update to 1.0.2:
  * SVG icons are not supported but doc still mentioned SVG
  * xdg-email can now be used without any e-mail address
  * do not use mktemp without arguments, it breaks on systems with
    certain older versions of mktemp
* Thu Sep 20 2007 dmueller@suse.de
- fix xdg-su outside KDE/GNOME (#309164)
* Thu Aug 30 2007 dmueller@suse.de
- fix xdg-su for XFCE (#304753)
* Tue May 22 2007 dmueller@suse.de
- add xdg-su (#275937)
* Mon Nov  6 2006 dmueller@suse.de
- update to 1.0.1:
  * Several shell syntax issues causing failures on Ubuntu 6.10
  * Spurious output on stdout when running xdg-desktop-menu
  * Non-ascii mailto URI handling of xdg-email on non-UTF8 locales
    under KDE
* Fri Oct 27 2006 dmueller@suse.de
- don't build as root
* Wed Sep 27 2006 dmueller@suse.de
- update to 1.0rc1:
  * for changes, see /usr/share/doc/packages/xdg-utils/ChangeLog
* Thu Jun 22 2006 dmueller@suse.de
- Initial package (TP1)
